---
title: 'Brightway: An open source framework for Life Cycle Assessment'
tags:
 - Python
 - LCA
authors:
 - name: Chris Mutel
   orcid: 0000-0002-7898-9862
   affiliation: 1
affiliations:
 - name: Paul Scherrer Institut
   index: 1
date: 5 April 2017
bibliography: paper.bib
---

# Summary

Brightway is an open source framework for Life Cycle Assessment (LCA) calculations in Python. The combination of a modular structure, the expressiveness and interactivity of Python and in particular Jupyter notebooks, and tuned calculation pathways allows for new research directions in Life Cycle Assessment. Brightway has been used in papers on meta-analysis of many inventory datasets [@wernet2011environmental], regionalized LCA [@mutel2011gis], and sensitivity analysis [@mutel2013two]. Brightway consists of three main modules: Brightway2-data [@bw2data] manages how data is stored and accessed; Brightway2-calc [@bw2calc] does static and Monte Carlo calculations; and Brightway2-IO [@bw2io] handles the import and export of LCA data from various sources. In addition to these libraries, helper libraries provide documentation and application examples [@brightway2], support for parameterized inventories [@bw2parameters], and a format for LCA data in arrays [@statsarrays]. A web page [@homepage], documentation [@bw2docs], and a development blog [@blog] are also available.

# References
